#
# spec file for package python-cauldron-notebook
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         skip_python39 1
Name:           python-cauldron-notebook
Version:        1.0.9
Release:        3.2
Summary:        Scientific Analysis Environment
License:        MIT
URL:            https://github.com/sernst/cauldron
Source:         https://github.com/sernst/cauldron/archive/v%{version}.tar.gz#/cauldron-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask
Requires:       python-Jinja2
Requires:       python-Markdown
Requires:       python-beautifulsoup4
Requires:       python-numpy
Requires:       python-pandas
Requires:       python-pygments
Requires:       python-requests
Requires:       python-waitress
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-bokeh
Recommends:     python-matplotlib
Recommends:     python-plotly
Recommends:     python-seaborn
Provides:       python-cauldron_notebook = %{version}-%{release}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module Markdown}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module bokeh}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module plotly}
BuildRequires:  %{python_module pygments}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module seaborn}
BuildRequires:  %{python_module waitress}
# /SECTION
%python_subpackages

%description
Interactive computing for complex data processing,
modeling and analysis in Python.

%prep
%setup -q -n cauldron-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/cauldron
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Tests only work on git repo
# %%check
# %%pytest

%post
%python_install_alternative cauldron

%postun
%python_uninstall_alternative cauldron

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/cauldron
%{python_sitelib}/cauldron
%{python_sitelib}/cauldron_notebook-%{version}.dist-info

%changelog
* Mon May  6 2024 pgajdos@suse.com
- remove superfluous sed
* Mon Mar  4 2024 Ben Greiner <code@bnavigator.de>
- Build PEP517 wheel
- Skip python39: no plotly anymore (due to xarray)
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to v1.0.9:
  * Add 3.10 support.
  * Remove 3.6 support.
  * Updates for major dependency changes.
* Thu Dec  9 2021 pgajdos@suse.com
- version update to 1.0.7
  * Improves handling of module reloading in shared libraries to avoid inter-dependencies from causing reload-order errors.
  * Adds version display to the web UI home screen for all three components for clarity with style alerting when key versions mismatch.
  * Also added hooks for APM to support API tuning and some backwards-compatible changes to the API for additional debugging clarity.
  * Refactored build configuration into yaml files for greater extensibility.
  * Updated web UI dependencies.
  * Drop support for Python 3.5 now that is has passed its end-of-life date.
  * Adds official support for Python 3.9 now that the DS stack libraries have released with 3.9 support as well.
  * Adds handling of decimal.Decimal types in a number notebook rendering cases.
  * Improved step test file matching for partial matches in cases where similar file names are found within the same project.
  * Improved notebook loading within the UI application.
* Thu Dec  9 2021 pgajdos@suse.com
- do not require pytest-runner for build, not required
* Wed Jan 27 2021 Benjamin Greiner <code@bnavigator.de>
- Disable python36 build, because SciPy dropped support for
  Python 3.6 and other NumPy related packages will drop it soon.
* Wed Jul  8 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.0.3
  * Improve step test file name matching when similar file names exist within a project.
  * Also improve the load process for project notebook displays in the UI application.
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 1.0.2
  * Restores Python 3.5 compatibility for lower patches.
  * Improves large file syncing between UI and kernels.
- Update to 1.0.1
  * Expanded color palette management in the plotter module,
  * Simplified step testing with partial step matching in run_set(STEP_NAME),
  * Fixes packaging of the UI in the pypi and conda packages.
- Update to 1.0.0
  * Major new release with a new web-based UI
* Tue Dec  3 2019 Todd R <toddrme2178@gmail.com>
- initial version
